janus_messages

Struct Query

pub struct Query<Q: QueryType> { /* private fields */ }
Represents a query for a specific batch identifier, received from a Collector as part of the collection flow.

Implementations

Source

impl<Q: QueryType> Query<Q>

pub fn new(query_body: Q::QueryBody) -> Self

Constructs a new query from its components.

This method would typically be used for code which is generic over the query type. Query-type specific code will typically call one of Self::new_time_interval or Self::new_fixed_size.

pub fn query_body(&self) -> &Q::QueryBody

Gets the query body included in this query.

This method would typically be used for code which is generic over the query type. Query-type specific code will typically call one of Self::batch_interval or Self::fixed_size_query.

Source

impl Query<TimeInterval>

pub fn new_time_interval(batch_interval: Interval) -> Self

Constructs a new query for a time-interval task.

pub fn batch_interval(&self) -> &Interval

Gets the batch interval associated with this query.

Source

impl Query<FixedSize>

pub fn new_fixed_size(fixed_size_query: FixedSizeQuery) -> Self

Constructs a new query for a fixed-size task.

pub fn fixed_size_query(&self) -> &FixedSizeQuery

Gets the fixed size query associated with this query.